<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for exclusive use with SkaDate Dating Software (http://www.skadate.com)
 * and is licensed under SkaDate Exclusive License by Skalfa LLC.
 *
 * Full text of this license can be found at http://www.skadate.com/sel.pdf
 */

/**
 * Service class.
 */
class MIDNIGHTTHEME_BOL_Service
{
    use OW_Singleton;

    const PLUGIN_KEY = "midnighttheme";

    const CN_TESTIMONIALS_NUMBER_LIST = "slider_testimonials_number_list";

    const MS_LANG_TEXT = "user_reviews_item_text";
    const MS_LANG_NAME = "user_reviews_item_name";
    const MS_LANG_LOCATION = "user_reviews_item_location";
    const HIW_LANG_TITLE = "how_block_item_title";
    const HIW_LANG_TEXT = "how_block_item_text";
    const HIW_NUMBER_LIST = [1,2,3];

    const SOCIAL_MEDIA_PREFIX_LINK = "link_";
    const SOCIAL_MEDIA_PREFIX_IS_VISIBLE = "is_visible_";
    const SOCIAL_MEDIA_LIST = [
        "facebook",
        "instagram",
        "pinterest",
        "twitter",
        "youtube",
        "google_plus",
    ];

    /**
     * @var MIDNIGHTTHEME_BOL_TestimonialsAvatarDao
     */
    private $testimonialsAvatarDao;

    /**
     * @var MIDNIGHTTHEME_BOL_MemberDao
     */
    private $memberDao;

    /**
     * @var MIDNIGHTTHEME_BOL_SocialNetworkDao
     */
    private $socialNetworkDao;

    private function __construct()
    {
        $this->testimonialsAvatarDao = MIDNIGHTTHEME_BOL_TestimonialsAvatarDao::getInstance();
        $this->memberDao = MIDNIGHTTHEME_BOL_MemberDao::getInstance();
        $this->socialNetworkDao = MIDNIGHTTHEME_BOL_SocialNetworkDao::getInstance();
    }

    public function getMobileExperienceConfigs()
    {
        $cmpConfigs = BOL_ComponentSettingDao::getInstance()
            ->findSettingList("index-SKMOBILEAPP_CMP_MobileExperience", ["banners", "show_first"]);
        $result = [
            "banners" => [
                "skadateios",
                "skandroid",
                "pwa"
            ],
            "show_first" => "skadateios",
            "ios_app_url" => OW::getConfig()->getValue('skmobileapp', "ios_app_url"),
            "android_app_url" => OW::getConfig()->getValue('skmobileapp', "android_app_url"),
        ];

        if (!empty($cmpConfigs[0]->value))
        {
            $result["banners"] = array_keys(json_decode($cmpConfigs[0]->value, true));
        }
        if (!empty($cmpConfigs[1]->value))
        {
            $result["show_first"] = $cmpConfigs[1]->value;
        }

        return $result;
    }

    public function getSocialNetworksLinksAndVisibility()
    {
        $values = OW::getConfig()->getValues(self::PLUGIN_KEY);
        $result = [];

        foreach (self::SOCIAL_MEDIA_LIST as $snName)
        {
            $result[$snName] = [
                "link" => $values[self::SOCIAL_MEDIA_PREFIX_LINK . $snName],
                "visibility" => $values[self::SOCIAL_MEDIA_PREFIX_IS_VISIBLE . $snName]
            ];
        }

        return $result;
    }

    public function getVisibleSocialNetworksLinks()
    {
        $values = $this->socialNetworkDao->findActiveSocialNetworks();

        return $this->formatSocialNetworks($values);
    }

    public function getSocialNetworks()
    {
        $values = $this->socialNetworkDao->findAllByOrder();

        return $this->formatSocialNetworks($values);
    }

    public function formatSocialNetworks( $values )
    {
        $result = [];

        foreach ( $values as $sn )
        {
            $link = $sn->link;
            if ( strpos($link, "http://") === 0 )
            {
                $link = str_replace("http", "https", $link);
            }
            else if ( strpos($link, "https://") === false )
            {
                $link = "https://{$link}";
            }

            $result[] = [
                "id" => $sn->id,
                "order" => $sn->order,
                "name" => $sn->name,
                "link" => $link,
                "active" => $sn->active,
                "wrapperClass" => $this->getImageBackgroundClass($sn->imgName),
                "img_url" => $this->getSocialNetworkImageUrl($sn->imgName)
            ];
        }

        return $result;
    }

    public function getImageBackgroundClass( $imageName = '', $path = '' )
    {
        if ( empty($path) )
        {
            $path = OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesDir() . "images/{$imageName}";
        }

        $isDark = $this->isDarkImage($path);

        return $isDark ? 'social-networks-light-bg' : 'social-networks-dark-bg';
    }

    public function isDarkImage( $imagePath )
    {
        $threshold = 128;
        $res = mime_content_type($imagePath);

        if ( $res == 'image/svg+xml' )
        {
            $svgContent = file_get_contents($imagePath);

            if ( preg_match_all('/fill=["\'](#[0-9A-Fa-f]{6}|#[0-9A-Fa-f]{3}|rgba?\([^)]+\))["\']/',
                $svgContent, $matches) )
            {
                $fillColorList = $matches[1];
                $lightColors = [];
                $darkColors = [];

                foreach ( $fillColorList as $color )
                {
                    $brightness = $this->calculateBrightness($color);

                    if ( $brightness >= $threshold )
                    {
                        $lightColors[] = $color;
                    }
                    else
                    {
                        $darkColors[] = $color;
                    }
                }

                return count($lightColors) <= count($darkColors);
            }

            return false;
        }

        $image = null;
        switch ( $res )
        {
            case 'image/jpeg':
            case 'image/jpg': $image = imagecreatefromjpeg($imagePath); break;
            case 'image/gif': $image = imagecreatefromgif($imagePath); break;
            case 'image/png': $image = imagecreatefrompng($imagePath); break;
        }

        if ( !$image )
        {
            return false;
        }

        $width = imagesx($image);
        $height = imagesy($image);
        $whitePixels = 0;
        $blackPixels = 0;

        for ( $x = 0; $x < $width; $x++ )
        {
            for ( $y = 0; $y < $height; $y++ )
            {
                $pixelColor = imagecolorat($image, $x, $y);
                $red = ($pixelColor >> 16) & 0xFF;
                $green = ($pixelColor >> 8) & 0xFF;
                $blue = $pixelColor & 0xFF;

                if ( $red > $threshold && $green > $threshold && $blue > $threshold )
                {
                    $whitePixels++;
                }
                elseif ( $red <= $threshold && $green <= $threshold && $blue <= $threshold )
                {
                    $blackPixels++;
                }
            }
        }

        imagedestroy($image);

        return $whitePixels <= $blackPixels;
    }

    public function calculateBrightness( $color ) {
        $color = ltrim($color, '#');

        $red = hexdec(substr($color, 0, 2));
        $green = hexdec(substr($color, 2, 2));
        $blue = hexdec(substr($color, 4, 2));

        return ($red + $green + $blue) / 3;
    }

    /**
     * Get social network image url.
     *
     * @param string $imgName
     * @return string|null
     */
    private function getSocialNetworkImageUrl( $imgName )
    {
        return $imgName
            ? OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesUrl() . "images/{$imgName}"
            : BOL_AvatarService::getInstance()->getDefaultAvatarUrl();
    }

    public function updateSocialNetworksLinks(array $snLinks, array $snVisibility)
    {
        $config = OW::getConfig();

        foreach ($snLinks as $snName => $snLink)
        {
            $config->saveConfig(self::PLUGIN_KEY, self::SOCIAL_MEDIA_PREFIX_LINK . $snName, $snLink);
            $config->saveConfig(self::PLUGIN_KEY, self::SOCIAL_MEDIA_PREFIX_IS_VISIBLE . $snName, $snVisibility[$snName]);
        }
    }

    public function getHowItWorksByNumberAndLangId($number, $langId = null)
    {
        if (!in_array($number, self::HIW_NUMBER_LIST))
        {
            return null;
        }

        $languageService = BOL_LanguageService::getInstance();
        $path = OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesUrl() . "images/";
        $langId = $langId ?? $languageService->getCurrent()->getId();

        $title = $languageService->getValue($langId, self::PLUGIN_KEY, self::HIW_LANG_TITLE . "_" . $number);
        $text = $languageService->getValue($langId, self::PLUGIN_KEY, self::HIW_LANG_TEXT . "_" . $number);

        $imgUrl = $path . OW::getConfig()->getValue(self::PLUGIN_KEY, "section_how_it_works_img_$number");

        return [
            "number" => $number,
            "title" => $title ? $title->getValue() : "",
            "text" => $text ? $text->getValue() : "",
            "img_url" => $imgUrl
        ];
    }

    public function getHowItWorksList()
    {
        $language = OW::getLanguage();
        $path = OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesUrl() . "images/";

        $howItWorksList = [];

        foreach ( self::HIW_NUMBER_LIST as $number )
        {
            $imgUrl = $path . OW::getConfig()->getValue(self::PLUGIN_KEY, "section_how_it_works_img_$number");

            $howItWorksList[] = [
                "number" => $number,
                "title" => $language->text(self::PLUGIN_KEY, self::HIW_LANG_TITLE . "_" . $number),
                "text" => $language->text(self::PLUGIN_KEY, self::HIW_LANG_TEXT . "_" . $number),
                "img_url" => $imgUrl
            ];
        }

        return $howItWorksList;
    }

    public function getHowItWorksCount()
    {
        return count(self::HIW_NUMBER_LIST);
    }

    public function updateHowItWorks($languageId, $title, $text, $imageName, $imagePath, $number)
    {
        $languageService = BOL_LanguageService::getInstance();

        if (!$number || !in_array($number, self::HIW_NUMBER_LIST))
        {
            return;
        }

        $languageService->addOrUpdateValue($languageId, self::PLUGIN_KEY, self::HIW_LANG_TITLE . "_" . $number, $title, false);
        $languageService->addOrUpdateValue($languageId, self::PLUGIN_KEY, self::HIW_LANG_TEXT . "_" . $number, $text, false);

        $languageService->generateCache($languageId);

        if ( $imageName && $imagePath )
        {
            $newImageName = $this->storeHowItWorks($number, $imageName, $imagePath);

            OW::getConfig()->saveConfig(self::PLUGIN_KEY, "section_how_it_works_img_$number", $newImageName);
        }
    }

    public function getTestimonialsByNumberAndLangId($number, $langId = null)
    {
        $numberList = OW::getConfig()->getValue(self::PLUGIN_KEY, self::CN_TESTIMONIALS_NUMBER_LIST);
        $numberList = json_decode($numberList, true);

        if (!in_array($number, $numberList))
        {
            return null;
        }

        $languageService = BOL_LanguageService::getInstance();
        $langId = $langId ?? $languageService->getCurrent()->getId();

        $text = $languageService->getValue($langId, self::PLUGIN_KEY, self::MS_LANG_TEXT . "_" . $number);
        $name = $languageService->getValue($langId, self::PLUGIN_KEY, self::MS_LANG_NAME . "_" . $number);
        $location = $languageService->getValue($langId, self::PLUGIN_KEY, self::MS_LANG_LOCATION . "_" . $number);

        return [
            "number" => $number,
            "text" => $text ? $text->getValue() : "",
            "name" => $name ? $name->getValue() : "",
            "location" => $location ? $location->getValue() : "",
            "avatar_url" => $this->getTestimonialsAvatarUrl($number)
        ];
    }

    public function getTestimonialsNumbers()
    {
        $numberList = OW::getConfig()->getValue(self::PLUGIN_KEY, self::CN_TESTIMONIALS_NUMBER_LIST);
        $language = OW::getLanguage();

        $sifted = [];
        foreach (json_decode($numberList, true) as $number)
        {
            if ($language->text(self::PLUGIN_KEY, self::MS_LANG_TEXT . "_" . $number, null, "") &&
                $language->text(self::PLUGIN_KEY, self::MS_LANG_NAME . "_" . $number, null, "") &&
                $language->text(self::PLUGIN_KEY, self::MS_LANG_LOCATION . "_" . $number, null, ""))
            {
                $sifted[] = $number;
            }
        }

        return $sifted;
    }

    public function getTestimonialsAvatars()
    {
        $avatars = [];

        foreach ($this->testimonialsAvatarDao->findAll() as $img)
        {
            $avatars[$img->number] = $this->getTestimonialsAvatarUrl($img->number);
        }

        return $avatars;
    }

    public function getTestimonialsList($first, $onPage)
    {
        $numberList = OW::getConfig()->getValue(self::PLUGIN_KEY, self::CN_TESTIMONIALS_NUMBER_LIST);
        $numberList = array_slice(json_decode($numberList, true), $first, $onPage);
        $testimonialsList = [];

        $language = OW::getLanguage();

        foreach ($numberList as $number)
        {
            $testimonialsList[] = [
                "number" => $number,
                "text" => $language->text(self::PLUGIN_KEY, self::MS_LANG_TEXT . "_" . $number, null, ""),
                "name" => $language->text(self::PLUGIN_KEY, self::MS_LANG_NAME . "_" . $number, null, ""),
                "location" => $language->text(self::PLUGIN_KEY, self::MS_LANG_LOCATION . "_" . $number, null, ""),
                "avatar_url" => $this->getTestimonialsAvatarUrl($number)
            ];
        }

        return $testimonialsList;
    }

    public function getTestimonialsCount()
    {
        $numberList = OW::getConfig()->getValue(self::PLUGIN_KEY, self::CN_TESTIMONIALS_NUMBER_LIST);

        return count(json_decode($numberList, true));
    }

    public function addOrUpdateTestimonials($languageId, $text, $name, $location, $imageName, $imagePath, $number = null)
    {
        $config = OW::getConfig();
        $languageService = BOL_LanguageService::getInstance();

        $numberList = $config->getValue(self::PLUGIN_KEY, self::CN_TESTIMONIALS_NUMBER_LIST);
        $numberList = json_decode($numberList, true);

        if (!$number || !in_array($number, $numberList))
        {
            $number = !empty($numberList) ? max($numberList) + 1 : 1;
        }

        $languageService->addOrUpdateValue($languageId, self::PLUGIN_KEY, self::MS_LANG_TEXT . "_" . $number, $text, false);
        $languageService->addOrUpdateValue($languageId, self::PLUGIN_KEY, self::MS_LANG_NAME . "_" . $number, $name, false);
        $languageService->addOrUpdateValue($languageId, self::PLUGIN_KEY, self::MS_LANG_LOCATION . "_" . $number, $location, false);

        $languageService->generateCache($languageId);

        if ($imageName && $imagePath)
        {
            $newImageName = $this->storeTestimonialsAvatar($number, $imageName, $imagePath);

            $this->testimonialsAvatarDao->saveImgName($number, $newImageName);
        }

        $numberList[] = $number;
        $numberList = array_unique($numberList);

        $config->saveConfig(self::PLUGIN_KEY, self::CN_TESTIMONIALS_NUMBER_LIST, json_encode($numberList));
    }

    public function deleteTestimonials($number)
    {
        $config = OW::getConfig();
        $languageService = BOL_LanguageService::getInstance();

        foreach ($languageService->getLanguages() as $BOL_Language)
        {
            $languageId = $BOL_Language->id;

            foreach ([self::MS_LANG_TEXT, self::MS_LANG_NAME, self::MS_LANG_LOCATION] as $langName)
            {
                $value = $languageService->getValue($languageId, self::PLUGIN_KEY, "{$langName}_{$number}");
                if ($value)
                {
                    $languageService->deleteValue($value, false);
                }
            }

            $languageService->generateCache($languageId);
        }

        // Remove testimonials number from storage
        $numberList = $config->getValue(self::PLUGIN_KEY, self::CN_TESTIMONIALS_NUMBER_LIST);
        $numberList = json_decode($numberList, true);
        $index = array_search($number, $numberList);
        if ($index != -1)
        {
            unset($numberList[$index]);
        }
        $numberList = array_values($numberList);
        $config->saveConfig(self::PLUGIN_KEY, self::CN_TESTIMONIALS_NUMBER_LIST, json_encode($numberList));

        // Remove testimonials img and its data
        $imgName = $this->testimonialsAvatarDao->getImgNameByNumber($number);
        $this->deleteTestimonialsAvatar($imgName);
        $this->testimonialsAvatarDao->deleteByNumber($number);
    }

    /**
     * Store testimonials avatar file.
     *
     * @param integer $number
     * @param string $filename
     * @param string $tmpFilePath
     */
    private function storeTestimonialsAvatar($number, $filename, $tmpFilePath)
    {
        $storage = OW::getStorage();

        $path = OW::getPluginManager()->getPlugin('midnighttheme')->getUserFilesDir() . "img_avatar";

        $formattedFilename = $this->testimonialsAvatarDao->getImgNameByNumber($number);

        if ($formattedFilename)
        {
            $formattedFilepath = "{$path}/{$formattedFilename}";

            if (file_exists($formattedFilepath))
            {
                $storage->removeFile($formattedFilepath);
            }
        }

        $formattedFilename = "author{$number}." . explode(".", $filename)[1];
        $formattedFilepath = "{$path}/{$formattedFilename}";

        @mkdir($path);

        $storage->copyFile($tmpFilePath, $formattedFilepath);

        return $formattedFilename;
    }

    /**
     * Delete testimonials avatar file.
     *
     * @param string $imgName
     */
    private function deleteTestimonialsAvatar($imgName)
    {
        $path = OW::getPluginManager()->getPlugin('midnighttheme')->getUserFilesDir() . "img_avatar";
        $formattedFilepath = "{$path}/{$imgName}";

        OW::getStorage()->removeFile($formattedFilepath);
    }

    /**
     * Get testimonials avatar url.
     *
     * @param integer $number
     * @return string|null
     */
    private function getTestimonialsAvatarUrl($number)
    {
        $imgName = $this->testimonialsAvatarDao->getImgNameByNumber($number);

        return $imgName
            ? OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesUrl() . "img_avatar/{$imgName}?" . uniqid()
            : BOL_AvatarService::getInstance()->getDefaultAvatarUrl();
    }

    public function addOrUpdateHeaderItem( $imageName, $imagePath, $number = null )
    {
        if ( $imageName && $imagePath )
        {
            $newImageName = $this->storeHeaderItem($number, $imageName, $imagePath);

            OW::getConfig()->saveConfig(self::PLUGIN_KEY, "section_header_img_$number", $newImageName);
        }
    }

    /**
     * Store header item file.
     *
     * @param integer $number
     * @param string $filename
     * @param string $tmpFilePath
     */
    private function storeHeaderItem( $number, $filename, $tmpFilePath )
    {
        $storage = OW::getStorage();

        $path = OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesDir() . "images";

        $formattedFilename = OW::getConfig()->getValue(self::PLUGIN_KEY, "section_header_img_$number");

        if ( $formattedFilename )
        {
            $formattedFilepath = "{$path}/{$formattedFilename}";

            if ( file_exists($formattedFilepath) )
            {
                $storage->removeFile($formattedFilepath);
            }
        }

        $formattedFilename = "header_img_$number." . explode(".", $filename)[1];
        $formattedFilepath = "{$path}/{$formattedFilename}";

        @mkdir($path);

        $storage->copyFile($tmpFilePath, $formattedFilepath);

        return $formattedFilename;
    }

    public function resetHeaderById( $number )
    {
        $path = OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesDir() . "images";
        $imageName = "header_default_{$number}.jpg";
        $imagePath = $path . '/' . $imageName;

        $this->addOrUpdateHeaderItem($imageName, $imagePath, $number);
    }

    public function getLatestUserList()
    {
        $membersIds = BOL_UserService::getInstance()->findLatestUserIdsList(1, 18);
        $avatarList = BOL_AvatarService::getInstance()->getAvatarsUrlList($membersIds, 2);
        $userNameList = BOL_UserService::getInstance()->getUserNamesForList($membersIds);

        $memberList = [];
        $i = 1;

        foreach ( $membersIds as $id )
        {
            $memberList[] = [
                "number" => $i,
                "name" => $userNameList[$id],
                "avatar_url" => $avatarList[$id]
            ];
        }

        return $memberList;
    }

    public function getMembers( $active = 'all' )
    {
        $members = $this->memberDao->findAllByOrder("ASC", $active);

        $memberList = [];

        foreach ( $members as $member )
        {
            $memberList[] = [
                "id" => $member->id,
                "name" => $member->name,
                "active" => $member->active,
                "avatar_url" => $this->getMemberAvatarUrl($member->imgName)
            ];
        }

        return $memberList;
    }

    public function setMembersActiveByIds( $ids = [], $active = true )
    {
        $memberList = $this->memberDao->findByIdList($ids);

        foreach ( $memberList as $member )
        {
            $member->active = $active;

            $this->memberDao->save($member);
        }
    }

    /**
     * Get member avatar url.
     *
     * @param string $imgName
     * @return string|null
     */
    private function getMemberAvatarUrl( $imgName )
    {
        return $imgName
            ? OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesUrl() . "img_avatar/{$imgName}"
            : BOL_AvatarService::getInstance()->getDefaultAvatarUrl();
    }

    public function getMemberById( $id )
    {
        return $this->memberDao->findById($id);
    }

    public function addOrUpdateMembers( $name, $active, $imageName, $imagePath, $id = null )
    {
        $member = ($id) ? $this->memberDao->findById($id) : new MIDNIGHTTHEME_BOL_Member();

        $member->name = $name;
        $member->active = $active;

        if ($imageName && $imagePath)
        {
            $newImageName = $this->storeMembers($member, $imageName, $imagePath);

            $member->imgName = $newImageName;
        }

        $this->memberDao->save($member);
    }

    /**
     * Store member avatar file.
     *
     * @param MIDNIGHTTHEME_BOL_Member $member
     * @param string $filename
     * @param string $tmpFilePath
     */
    private function storeMembers( $member, $filename, $tmpFilePath )
    {
        $storage = OW::getStorage();

        $path = OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesDir() . "img_avatar";

        $formattedFilename = $member->imgName;

        if ( $formattedFilename )
        {
            $formattedFilepath = "{$path}/{$formattedFilename}";

            if ( file_exists($formattedFilepath) )
            {
                $storage->removeFile($formattedFilepath);
            }
        }

        $formattedFilename = uniqid("member") . "." . explode(".", $filename)[1];
        $formattedFilepath = "{$path}/{$formattedFilename}";

        @mkdir($path);

        $storage->copyFile($tmpFilePath, $formattedFilepath);

        return $formattedFilename;
    }

    /**
     * Delete member by number
     *
     * @param $id
     * @return void
     */
    public function deleteMember( $id )
    {
        /** @var MIDNIGHTTHEME_BOL_MemberDao $member */
        $member = $this->memberDao->findById($id);

        $this->deleteMemberAvatar($member->imgName);
        $this->memberDao->deleteById($id);
    }

    /**
     * Update numbers of members
     *
     * @param $number
     * @return void
     */
    public function updateNumberMembers( $number )
    {
        $members = $this->memberDao->findAllByOrder();

        foreach ( $members as $member )
        {
            if ( $member->number > $number )
            {
                $member->number--;
                $this->memberDao->save($member);
            }
        }
    }

    /**
     * Delete member avatar file.
     *
     * @param string $imgName
     */
    private function deleteMemberAvatar( $imgName )
    {
        $path = OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesDir() . "img_avatar";
        $formattedFilepath = "{$path}/{$imgName}";

        OW::getStorage()->removeFile($formattedFilepath);
    }

    public function getSocialNetworkById( $id )
    {
        return $this->socialNetworkDao->findById($id);
    }

    public function addOrUpdateSocialNetwork( $name, $link, $active, $imageName, $imagePath, $id = null )
    {
        /** @var MIDNIGHTTHEME_BOL_SocialNetwork $socialNetwork */
        $socialNetwork = ($id) ? $this->socialNetworkDao->findById($id) : new MIDNIGHTTHEME_BOL_SocialNetwork();

        if ( !$id )
        {
            $socialNetwork->order = $this->getMaxOrder() + 1;
        }

        $socialNetwork->name = $name;
        $socialNetwork->link = $link;
        $socialNetwork->active = $active;

        if ( $imageName && $imagePath )
        {
            $newImageName = $this->storeSocialNetworkImage($socialNetwork, $imageName, $imagePath);

            $socialNetwork->imgName = $newImageName;
        }

        $this->socialNetworkDao->save($socialNetwork);
    }

    public function getMaxOrder()
    {
        $query = "SELECT MAX(`order`) AS 'max_order' FROM `{$this->socialNetworkDao->getTableName()}`";

        return OW::getDbo()->queryForColumn($query);
    }

    /**
     * Store social network image.
     *
     * @param MIDNIGHTTHEME_BOL_SocialNetwork $network
     * @param string $filename
     * @param string $tmpFilePath
     */
    private function storeSocialNetworkImage( $network, $filename, $tmpFilePath )
    {
        $storage = OW::getStorage();

        $path = OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesDir() . "images";

        $formattedFilename = $network->imgName;

        if ( $formattedFilename )
        {
            $formattedFilepath = "{$path}/{$formattedFilename}";

            if ( file_exists($formattedFilepath) )
            {
                $storage->removeFile($formattedFilepath);
            }
        }

        $formattedFilename = "network" . uniqid() . "." . explode(".", $filename)[1];
        $formattedFilepath = "{$path}/{$formattedFilename}";

        @mkdir($path);

        $storage->copyFile($tmpFilePath, $formattedFilepath);

        return $formattedFilename;
    }

    public function updateSocialNetworksOrder( $ids )
    {
        $socialNetworkList = $this->socialNetworkDao->findAll();

        foreach ( $socialNetworkList as $network )
        {
            if ( isset($ids[$network->id]) )
            {
                $network->order = $ids[$network->id];
                $this->socialNetworkDao->save($network);
            }
        }
    }

    public function refreshSocialNetworksOrder( $order )
    {
        $socialNetworkList = $this->socialNetworkDao->findAll();

        foreach ( $socialNetworkList as $network )
        {
            if ( $network->order > $order )
            {
                $network->order--;
                $this->socialNetworkDao->save($network);
            }
        }
    }

    /**
     * Delete social network by id
     *
     * @param $id
     * @return void
     */
    public function deleteSocialNetwork( $id )
    {
        /** @var MIDNIGHTTHEME_BOL_SocialNetwork $socialNetwork */
        $socialNetwork = $this->socialNetworkDao->findById($id);

        if ( empty($socialNetwork) )
        {
            return;
        }

        $order = $socialNetwork->order;

        $this->deleteSocialNetworkImage($socialNetwork->imgName);
        $this->socialNetworkDao->deleteById($id);

        $this->refreshSocialNetworksOrder($order);
    }

    /**
     * Delete social network image.
     *
     * @param string $imgName
     */
    private function deleteSocialNetworkImage( $imgName )
    {
        $path = OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesDir() . "images";
        $formattedFilepath = "{$path}/{$imgName}";

        OW::getStorage()->removeFile($formattedFilepath);
    }

    /**
     * Store how it works item file.
     *
     * @param integer $number
     * @param string $filename
     * @param string $tmpFilePath
     */
    private function storeHowItWorks( $number, $filename, $tmpFilePath )
    {
        $storage = OW::getStorage();

        $path = OW::getPluginManager()->getPlugin(self::PLUGIN_KEY)->getUserFilesDir() . "images";

        $formattedFilename = OW::getConfig()->getValue(self::PLUGIN_KEY, "section_how_it_works_img_$number");

        if ( $formattedFilename )
        {
            $formattedFilepath = "{$path}/{$formattedFilename}";

            if ( file_exists($formattedFilepath) )
            {
                $storage->removeFile($formattedFilepath);
            }
        }

        $formattedFilename = "how_it_works_$number." . explode(".", $filename)[1];
        $formattedFilepath = "{$path}/{$formattedFilename}";

        @mkdir($path);

        $storage->copyFile($tmpFilePath, $formattedFilepath);

        return $formattedFilename;
    }
}
