<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Data Access Object for `testimonials_avatar` table.
 */
class MIDNIGHTTHEME_BOL_TestimonialsAvatarDao extends OW_BaseDao
{
    use OW_Singleton;

    /**
     * Class constructor.
     */
    protected function __construct()
    {
        parent::__construct();
    }

    /**
     * Get dto class name.
     * 
     * @return string
     */
    public function getDtoClassName()
    {
        return "MIDNIGHTTHEME_BOL_TestimonialsAvatar";
    }

    /**
     * Get table name.
     * 
     * @return string
     */
    public function getTableName()
    {
        return OW_DB_PREFIX . "midnighttheme_testimonials_avatar";
    }

    /**
     * Returns testimonials avatar by its number.
     *
     * @param number $number
     * @return string|null
     */
    public function getImgNameByNumber($number)
    {
        $example = new OW_Example();
        $example->andFieldEqual("number", $number);
        $testimonialsAvatar = $this->findObjectByExample($example);

        return $testimonialsAvatar ? $testimonialsAvatar->imgName : null;
    }

    /**
     * Save image name and its number.
     *
     * @param number $number
     * @param string $imgName
     * @return string|null
     */
    public function saveImgName($number, $imgName)
    {
        $example = new OW_Example();
        $example->andFieldEqual("number", $number);
        $testimonialsAvatar = $this->findObjectByExample($example);

        if (!$testimonialsAvatar)
        {
            $testimonialsAvatar = new MIDNIGHTTHEME_BOL_TestimonialsAvatar();
            $testimonialsAvatar->number = $number;
        }

        $testimonialsAvatar->imgName = $imgName;

        $this->save($testimonialsAvatar);
    }

    /**
     * Delete testimonials by its number.
     *
     * @param integer $number
     * @return void
     */
    public function deleteByNumber($number)
    {
        $example = new OW_Example();
        $example->andFieldEqual("number", $number);

        $this->deleteByExample($example);
    }
}
