<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Add testimonials form class.
 */
class MIDNIGHTTHEME_CLASS_AddSocialNetworkForm extends Form
{
    const FIELD_NAME_ORDER = 'order';
    const FIELD_NAME_NAME = 'name';
    const FIELD_NAME_LINK = 'link';
    const FIELD_NAME_ACTIVE = 'active';
    const FIELD_NAME_IMAGE = 'image';
    const FIELD_NAME_SAVE = 'save';

    public function __construct()
    {
        parent::__construct('add-social-network-form');

        $this->setEnctype('multipart/form-data');
        $this->setAction(OW::getRouter()->urlForRoute('midnighttheme_add_form_handler_social_network'));

        $this->generateControls();
    }

    protected function generateControls()
    {
        $languageService = BOL_LanguageService::getInstance();
        $lang = OW::getLanguage();

        $name = new TextField(self::FIELD_NAME_NAME);
        $name->setLabel($lang->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_label_sn_name'));
        $this->addElement($name);

        $link = new TextField(self::FIELD_NAME_LINK);
        $link->setLabel($lang->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_label_sn_link'));
        $this->addElement($link);

        $active = new CheckboxField(self::FIELD_NAME_ACTIVE);
        $active->setLabel($lang->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, "admin_label_sn_active"));
        $this->addElement($active);

        $allowedMimeTypes = ['image/gif', 'image/jpeg', 'image/jpg', 'image/png', 'image/svg+xml'];
        $image = new FileField(self::FIELD_NAME_IMAGE);
        if ( $this->getName() == 'add-social-network-form' && !isset($_FILES[self::FIELD_NAME_IMAGE]) )
        {
            $image->setRequired();
        }
        $image->setLabel($lang->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_label_sn_image'));
        $image->addAttribute('accept', implode(',', $allowedMimeTypes));
        $image->addValidator(
            new MIDNIGHTTHEME_CLASS_FileValidator(
                $image->getName(),
                $image->getId(),
                (int) OW::getConfig()->getValue('base', 'attch_file_max_size_mb'),
                $allowedMimeTypes
            )
        );
        $this->addElement($image);

        $submit = new Submit(self::FIELD_NAME_SAVE);
        $submit->setValue($lang->text('base', 'pages_add_submit'));
        $this->addElement($submit);
    }

    public function process( $data )
    {
        if ($this->isValid($data))
        {
            $name = $data[self::FIELD_NAME_NAME];
            $link = $data[self::FIELD_NAME_LINK];
            $active = isset($data[self::FIELD_NAME_ACTIVE]) && $data[self::FIELD_NAME_ACTIVE] === "on" ? "1" : "0";
            $imageFilename = $_FILES[self::FIELD_NAME_IMAGE]['name'];
            $imageFilepath = $_FILES[self::FIELD_NAME_IMAGE]['tmp_name'];

            MIDNIGHTTHEME_BOL_Service::getInstance()
                ->addOrUpdateSocialNetwork($name, $link, $active, $imageFilename, $imageFilepath);
        }
    }
}
