<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Add testimonials form class.
 */
class MIDNIGHTTHEME_CLASS_AddTestimonialsForm extends Form
{
    const FIELD_NAME_LANGUAGE = 'language';
    const FIELD_NAME_TEXT = 'text';
    const FIELD_NAME_NAME = 'name';
    const FIELD_NAME_LOCATION = 'location';
    const FIELD_NAME_IMAGE = 'image';
    const FIELD_NAME_SAVE = 'save';

    public function __construct()
    {
        parent::__construct('add-testimonials-form');

        $this->setEnctype('multipart/form-data');
        $this->setAction(OW::getRouter()->urlForRoute('midnighttheme_add_form_handler_testimonials'));

        $this->generateControls();
    }

    protected function generateControls()
    {
        $languageService = BOL_LanguageService::getInstance();
        $lang = OW::getLanguage();

        $language = new Selectbox(self::FIELD_NAME_LANGUAGE);
        $language->setRequired();
        $language->setLabel($lang->text('midnighttheme', 'admin_label_ms_language'));
        foreach ($languageService->getLanguages() as $BOL_Language)
        {
            $language->addOption($BOL_Language->id, $BOL_Language->label);
        }
        $language->setValue($languageService->getCurrent()->getId());
        $this->addElement($language);

        $text = new Textarea(self::FIELD_NAME_TEXT);
        $text->setLabel($lang->text('midnighttheme', 'admin_label_ms_text'));
        $this->addElement($text);

        $name = new TextField(self::FIELD_NAME_NAME);
        $name->setLabel($lang->text('midnighttheme', 'admin_label_ms_name'));
        $this->addElement($name);

        $location = new TextField(self::FIELD_NAME_LOCATION);
        $location->setLabel($lang->text('midnighttheme', 'admin_label_ms_location'));
        $this->addElement($location);

        $allowedMimeTypes = ['image/gif', 'image/jpeg', 'image/jpg', 'image/png'];
        $image = new FileField(self::FIELD_NAME_IMAGE);
        if ($this->getName() == 'add-testimonials-form' && !isset($_FILES[self::FIELD_NAME_IMAGE]))
        {
            $image->setRequired();
        }
        $image->setLabel($lang->text('midnighttheme', 'admin_label_ms_avatar'));
        $image->addAttribute('accept', implode(',', $allowedMimeTypes));
        $image->addValidator(
            new MIDNIGHTTHEME_CLASS_FileValidator(
                $image->getName(),
                $image->getId(),
                (int) OW::getConfig()->getValue('base', 'attch_file_max_size_mb'),
                $allowedMimeTypes
            )
        );
        $this->addElement($image);

        $submit = new Submit(self::FIELD_NAME_SAVE);
        $submit->setValue($lang->text('base', 'pages_add_submit'));
        $this->addElement($submit);
    }

    public function process($data)
    {
        if ($this->isValid($data))
        {
            $languageId = $data[self::FIELD_NAME_LANGUAGE];
            $text = $data[self::FIELD_NAME_TEXT];
            $name = $data[self::FIELD_NAME_NAME];
            $location = $data[self::FIELD_NAME_LOCATION];
            $imageFilename = $_FILES[self::FIELD_NAME_IMAGE]['name'];
            $imageFilepath = $_FILES[self::FIELD_NAME_IMAGE]['tmp_name'];

            MIDNIGHTTHEME_BOL_Service::getInstance()
                ->addOrUpdateTestimonials($languageId, $text, $name, $location, $imageFilename, $imageFilepath);
        }
    }
}
