<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Edit testimonials form class.
 */
class MIDNIGHTTHEME_CLASS_EditHeaderItemForm extends Form
{
    const FIELD_NAME_NUMBER = "number";
    const FIELD_NAME_IMAGE = 'image';
    const FIELD_NAME_SAVE = 'save';

    protected $number;

    public function __construct( $number )
    {
        parent::__construct('edit-header-item-form');

        $this->number = (int) $number;

        $this->setEnctype('multipart/form-data');
        $this->setAction(OW::getRouter()->urlForRoute('midnighttheme_edit_form_handler_header_item'));

        $this->generateControls();

        $numberField = new HiddenField(self::FIELD_NAME_NUMBER);
        $numberField->setRequired();
        $numberField->setValue($number);
        $this->addElement($numberField);

        $path = OW::getPluginManager()->getPlugin(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY)->getUserFilesUrl() . "images/";
        $data = $path . OW::getConfig()->getValue(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, "section_header_img_$number");

        $this->getElement(self::FIELD_NAME_IMAGE)->setValue($data);
    }

    protected function generateControls()
    {
        $lang = OW::getLanguage();

        $allowedMimeTypes = ['image/gif', 'image/jpeg', 'image/jpg', 'image/png'];
        $image = new FileField(self::FIELD_NAME_IMAGE);
        if ($this->getName() == 'add-header-item-form' && !isset($_FILES[self::FIELD_NAME_IMAGE]))
        {
            $image->setRequired();
        }
        $image->setLabel($lang->text('midnighttheme', 'admin_label_header_image'));
        $image->addAttribute('accept', implode(',', $allowedMimeTypes));
        $image->addValidator(
            new MIDNIGHTTHEME_CLASS_FileValidator(
                $image->getName(),
                $image->getId(),
                (int) OW::getConfig()->getValue('base', 'attch_file_max_size_mb'),
                $allowedMimeTypes
            )
        );
        $this->addElement($image);

        $submit = new Submit(self::FIELD_NAME_SAVE);
        $submit->setValue($lang->text('base', 'pages_add_submit'));
        $this->addElement($submit);
    }

    public function process($data)
    {
        if ($this->isValid($data))
        {
            $imageFilename = $_FILES[self::FIELD_NAME_IMAGE]['name'];
            $imageFilepath = $_FILES[self::FIELD_NAME_IMAGE]['tmp_name'];

            MIDNIGHTTHEME_BOL_Service::getInstance()
                ->addOrUpdateHeaderItem($imageFilename, $imageFilepath, $this->number);
        }
    }
}
