<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Edit how it works form class.
 */
class MIDNIGHTTHEME_CLASS_EditHowItWorksForm extends Form
{
    const FIELD_NAME_NUMBER = "number";
    const FIELD_NAME_LANGUAGE = 'language';
    const FIELD_NAME_TITLE = 'title';
    const FIELD_NAME_TEXT = 'text';
    const FIELD_NAME_IMAGE = 'image';
    const FIELD_NAME_SAVE = 'save';

    protected $number;

    public function __construct($number)
    {
        parent::__construct('edit-how-it-works-form');

        $this->number = (int) $number;

        $this->setEnctype('multipart/form-data');
        $this->setAction(OW::getRouter()->urlForRoute('midnighttheme_edit_form_handler_how_it_works'));

        $this->generateControls();

        $numberField = new HiddenField(self::FIELD_NAME_NUMBER);
        $numberField->setRequired();
        $numberField->setValue($number);
        $this->addElement($numberField);

        $data = MIDNIGHTTHEME_BOL_Service::getInstance()->getHowItWorksByNumberAndLangId($this->number);
        $this->getElement(self::FIELD_NAME_TITLE)->setValue($data["title"]);
        $this->getElement(self::FIELD_NAME_TEXT)->setValue($data["text"]);
        $this->getElement(self::FIELD_NAME_IMAGE)->setValue($data["img_url"]);
    }

    protected function generateControls()
    {
        $languageService = BOL_LanguageService::getInstance();
        $lang = OW::getLanguage();

        $language = new Selectbox(self::FIELD_NAME_LANGUAGE);
        $language->setRequired();
        $language->setLabel($lang->text('midnighttheme', 'admin_label_hiw_language'));
        foreach ($languageService->getLanguages() as $BOL_Language)
        {
            $language->addOption($BOL_Language->id, $BOL_Language->label);
        }
        $language->setValue($languageService->getCurrent()->getId());
        $this->addElement($language);

        $title = new TextField(self::FIELD_NAME_TITLE);
        $title->setRequired();
        $title->setLabel($lang->text('midnighttheme', 'admin_label_hiw_title'));
        $this->addElement($title);

        $text = new Textarea(self::FIELD_NAME_TEXT);
        $text->setRequired();
        $text->setLabel($lang->text('midnighttheme', 'admin_label_hiw_text'));
        $this->addElement($text);

        $allowedMimeTypes = ['image/gif', 'image/jpeg', 'image/jpg', 'image/png', 'image/svg+xml'];
        $image = new FileField(self::FIELD_NAME_IMAGE);
        $image->setLabel($lang->text('midnighttheme', 'admin_label_hiw_image'));
        $image->addAttribute('accept', implode(',', $allowedMimeTypes));
        $image->addValidator(
            new MIDNIGHTTHEME_CLASS_FileValidator(
                $image->getName(),
                $image->getId(),
                (int) OW::getConfig()->getValue('base', 'attch_file_max_size_mb'),
                $allowedMimeTypes
            )
        );
        $this->addElement($image);

        $submit = new Submit(self::FIELD_NAME_SAVE);
        $submit->setValue($lang->text('base', 'pages_add_submit'));
        $this->addElement($submit);
    }

    public function process($data)
    {
        if ($this->isValid($data))
        {
            $languageId = $data[self::FIELD_NAME_LANGUAGE];
            $title = $data[self::FIELD_NAME_TITLE];
            $text = $data[self::FIELD_NAME_TEXT];
            $imageFilename = $_FILES[self::FIELD_NAME_IMAGE]['name'];
            $imageFilepath = $_FILES[self::FIELD_NAME_IMAGE]['tmp_name'];


            MIDNIGHTTHEME_BOL_Service::getInstance()->updateHowItWorks($languageId, $title, $text, $imageFilename, $imageFilepath, $this->number);
        }
    }
}
