<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Edit social network form class.
 */
class MIDNIGHTTHEME_CLASS_EditSocialNetworkForm extends MIDNIGHTTHEME_CLASS_AddSocialNetworkForm
{
    const FIELD_NAME_ID = "id";

    protected $id;

    public function __construct( $id )
    {
        Form::__construct('edit-social-network-form');

        $this->id = (int) $id;

        $this->setEnctype('multipart/form-data');
        $this->setAction(OW::getRouter()->urlForRoute('midnighttheme_edit_form_handler_social_network'));

        $this->generateControls();

        $idField = new HiddenField(self::FIELD_NAME_ID);
        $idField->setRequired();
        $idField->setValue($id);
        $this->addElement($idField);

        /** @var MIDNIGHTTHEME_BOL_SocialNetwork $socialNetwork */
        $socialNetwork = MIDNIGHTTHEME_BOL_Service::getInstance()->getSocialNetworkById($id);

        $path = OW::getPluginManager()->getPlugin(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY)->getUserFilesUrl() . "images/";
        $dataUrl = $path . $socialNetwork->imgName;

        $this->getElement(self::FIELD_NAME_NAME)->setValue($socialNetwork->name);
        $this->getElement(self::FIELD_NAME_IMAGE)->setValue($dataUrl);
        $this->getElement(self::FIELD_NAME_LINK)->setValue($socialNetwork->link);
        $this->getElement(self::FIELD_NAME_ACTIVE)->setValue($socialNetwork->active);
    }

    public function process($data)
    {
        if ($this->isValid($data))
        {
            $name = $data[self::FIELD_NAME_NAME];
            $link = $data[self::FIELD_NAME_LINK];
            $active = isset($data[self::FIELD_NAME_ACTIVE]) && $data[self::FIELD_NAME_ACTIVE] === "on" ? "1" : "0";
            $imageFilename = $_FILES[self::FIELD_NAME_IMAGE]['name'];
            $imageFilepath = $_FILES[self::FIELD_NAME_IMAGE]['tmp_name'];

            MIDNIGHTTHEME_BOL_Service::getInstance()
                ->addOrUpdateSocialNetwork($name, $link, $active, $imageFilename, $imageFilepath, $this->id);
        }
    }
}
