<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Event handler class.
 */
class MIDNIGHTTHEME_CLASS_EventHandler
{
    use OW_Singleton;

    public function init()
    {
        $eventManager = OW::getEventManager();

        $eventManager->bind(OW_EventManager::ON_APPLICATION_INIT, array($this, "onApplicationInit"));
        $eventManager->bind(OW_EventManager::ON_BEFORE_DOCUMENT_RENDER, array($this, "onBeforeDocumentRender"));
        $eventManager->bind("class.get_instance.USEARCH_CMP_QuickSearch", array($this, "onInstanceOf__USEARCH_CMP_QuickSearch"));
        $eventManager->bind("class.get_instance.BASE_CMP_QuickLinksWidget", array($this, "onInstanceOf__BASE_CMP_QuickLinksWidget"));
    }

    public function onApplicationInit(OW_Event $event)
    {
        $viewRenderer = OW_ViewRenderer::getInstance();
        $viewRenderer->assignVar('midnightThemeSettingsAvailable', true);
    }

    public function onBeforeDocumentRender(OW_Event $event)
    {
        if (OW::getRequest()->isAjax())
        {
            return;
        }

        $usedRoute = OW::getRouter()->getUsedRoute();

        if ($usedRoute) {
            $routeName = OW::getRouter()->getUsedRoute()->getRouteName();
            $routePath = OW::getRouter()->getUsedRoute()->getRoutePath();

            /// Update date field value
            if (in_array($routeName, ['base_join', 'base_edit']) || in_array($routePath, ['join', 'profile/edit'])) {
                OW::getDocument()->addOnloadScript("
                    OW.bind('form.date_field_changed', function (param) {
                        jcf.refresh(this);
                    });
                ");
            }

            $request = OW::getRequestHandler()->getHandlerAttributes();

            if ( $routeName === "static_sign_in" || (isset($request['controller'], $request['action'])
                    && $request['controller'] == 'SMSVERIFICATION_CTRL_MainController'
                    && $request['action'] == 'inputNumber') )
            {
                $currentThemeStaticUrl = OW::getThemeManager()->getCurrentTheme()->getStaticUrl();

                OW::getDocument()->addScript("{$currentThemeStaticUrl}libs/jcf/js/jcf.js");
                OW::getDocument()->addScript("{$currentThemeStaticUrl}libs/jcf/js/jcf.select.js");
                OW::getDocument()->addScript("{$currentThemeStaticUrl}libs/jcf/js/jcf.radio.js");
                OW::getDocument()->addScript("{$currentThemeStaticUrl}libs/jcf/js/jcf.checkbox.js");
                OW::getDocument()->addOnloadScript("
                    $(document).ready(function () {
                        $(function() {
                            jcf.replaceAll();
                        });
                    });
                ");
            }
        }
    }

    public function onInstanceOf__USEARCH_CMP_QuickSearch(OW_Event $event)
    {
        $event->setData(OW::getClassInstance("MIDNIGHTTHEME_CMP_QuickSearch"));
    }

    public function onInstanceOf__BASE_CMP_QuickLinksWidget(OW_Event $event)
    {
        $widgetParameter = $event->getParams()["arguments"][0];

        $event->setData(OW::getClassInstance("MIDNIGHTTHEME_CMP_QuickLinksWidget", $widgetParameter));
    }
}
