<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * File validator class.
 */
class MIDNIGHTTHEME_CLASS_FileValidator extends OW_Validator
{
    protected $fieldName;
    protected $fieldId;
    protected $allowedFileSize;
    protected $allowedMimeTypes;

    protected $errorMessageBigFile;
    protected $errorMessageNowAllowedMimeType;

    /**
     * Constructor.
     *
     * @param string $fieldName
     * @param string $fieldId
     * @param integer $allowedFileSize
     * @param array $allowedMimeTypes
     */
    public function __construct($fieldName, $fieldId, $allowedFileSize, $allowedMimeTypes)
    {
        $this->fieldName = $fieldName;
        $this->fieldId = $fieldId;
        $this->allowedFileSize = $allowedFileSize;
        $this->allowedMimeTypes = $allowedMimeTypes;

        $this->errorMessageBigFile = OW::getLanguage()->text('midnighttheme', 'file_validator_error_filesize_exceeded', ['size' => $allowedFileSize]);
        $this->errorMessageNowAllowedMimeType = OW::getLanguage()->text('midnighttheme', 'file_validator_error_filetype_not_allowed');

        $this->setErrorMessage('File Validator Error!');
    }

    /**
     * @see OW_Validator::isValid()
     *
     * @param mixed $value
     */
    public function isValid($value)
    {
        $file = $_FILES[$this->fieldName];

        if (!$file['tmp_name'])
        {
            return true;
        }

        return $file['size'] / 1024 / 1024 < $this->allowedFileSize && in_array($file['type'], $this->allowedMimeTypes, true);
    }

    /**
     * @see OW_Validator::getJsValidator()
     *
     * @return string
     */
    public function getJsValidator()
    {
        $allowedMimeTypes = implode(', ', array_map(function($value) { return "'{$value}'"; }, $this->allowedMimeTypes));

        return "{
        	validate: function(value) {
        	    const fileEl = document.getElementById('{$this->fieldId}').files[0];
        	    
        	    if (!fileEl) {
        	        return;
        	    }
        	    
        	    const sizeMb = fileEl.size / 1024 / 1024;
        	    const mimeType = fileEl.type;
        	    
        	    if (sizeMb > {$this->allowedFileSize}) {
        	        throw " . json_encode($this->errorMessageBigFile) . ";
        	    }
        	    else if ([{$allowedMimeTypes}].indexOf(mimeType) === -1) {
        	        throw " . json_encode($this->errorMessageNowAllowedMimeType) . ";
        	    }
        	    
        	    console.log([{$allowedMimeTypes}], sizeMb, mimeType);
            },
        	getErrorMessage: function() {
        	    return " . json_encode($this->getError()) . ";
        	}
        }";
    }
}
