<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Members settings form class.
 */

class MIDNIGHTTHEME_CLASS_MembersSettingsForm extends Form
{
    public function __construct()
    {
        parent::__construct('members-settings-form');

        $lang = OW::getLanguage();
        $pluginKey = MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY;

        $isRealUsers = new CheckboxField('isRealUsers');
        $isRealUsers->setValue(OW::getConfig()->getValue($pluginKey, 'section_members_is_real_users'));
        $isRealUsers->setLabel($lang->text($pluginKey, 'label_section_members_is_real_members'));
        $isRealUsers->setDescription($lang->text($pluginKey, 'label_section_members_is_real_members_desc'));

        $this->addElement($isRealUsers);

        $isRandom = new CheckboxField('isRandom');
        $isRandom->setValue(OW::getConfig()->getValue($pluginKey, 'section_members_is_random'));
        $isRandom->setLabel($lang->text($pluginKey, 'label_section_members_is_random'));
        $isRandom->setDescription($lang->text($pluginKey, 'label_section_members_is_random_desc'));

        $this->addElement($isRandom);

        $actionUrl = OW::getRouter()->urlForRoute('midnighttheme_ajax_save_configs');

        OW::getDocument()->addOnloadScript("
            $('#{$isRealUsers->getId()}, #{$isRandom->getId()}').change(function() {
                var selfInput = this;
                $.ajax({
                    type: 'POST',
                    url: '{$actionUrl}',
                    data: $('#{$this->getId()}').serialize(),
                    dataType: 'json',
                    success: function(response) {
                        if (response.result) {
                            OW.info('{$lang->text($pluginKey, 'members_settings_updated')}');
                        }
                        else {
                            OW.error(response.message);
                            $(selfInput).attr('checked', false);
                            
                            return;
                        }
                        
                        var wrapper = document.getElementById('fakeMemberSection');
                        if (response.hideMembers) {
                            $(wrapper).removeClass('ow_hidden');
                            $(wrapper).addClass('ow_hidden');
                        }
                        else {
                            $(wrapper).removeClass('ow_hidden');
                        }
                    },
                });
            });
        ");
    }

    public function process( $data = [] )
    {
        if ( empty($data) )
        {
            $data = $this->getValues();
        }

        $config = OW::getConfig();
        $pluginKey = MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY;

        $config->saveConfig($pluginKey, 'section_members_is_real_users', isset($data['isRealUsers']) && $data['isRealUsers'] == 'on');
        $config->saveConfig($pluginKey, 'section_members_is_random', isset($data['isRandom']) && $data['isRandom'] == 'on');
    }
}
