<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Testimonials settings form class.
 */

class MIDNIGHTTHEME_CLASS_TestimonialsSettingsForm extends Form
{
    public function __construct()
    {
        parent::__construct('testimonials-settings-form');

        $lang = OW::getLanguage();
        $pluginKey = MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY;

        $isRandom = new CheckboxField('isRandom');
        $isRandom->setValue(OW::getConfig()->getValue($pluginKey, 'section_testimonials_is_random'));
        $isRandom->setLabel($lang->text($pluginKey, 'label_section_testimonials_is_random'));
        $isRandom->setDescription($lang->text($pluginKey, 'label_section_testimonials_is_random_desc'));

        $this->addElement($isRandom);

        $actionUrl = OW::getRouter()->urlForRoute('midnighttheme_ajax_save_configs');

        OW::getDocument()->addOnloadScript("
            $('#{$isRandom->getId()}').change(function() {
                $.ajax({
                    type: 'POST',
                    url: '{$actionUrl}',
                    data: $('#{$this->getId()}').serialize(),
                    dataType: 'json',
                    success: function(response) {
                        OW.info('{$lang->text($pluginKey, 'testimonials_settings_updated')}');
                    },
                });
            });
        ");
    }

    public function process( $data = [] )
    {
        if ( empty($data) )
        {
            $data = $this->getValues();
        }

        $config = OW::getConfig();
        $pluginKey = MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY;

        $config->saveConfig($pluginKey, 'section_testimonials_is_random', isset($data['isRandom']) && $data['isRandom'] == 'on');
    }
}
