<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Add social network component class.
 */
class MIDNIGHTTHEME_CMP_AddSocialNetwork extends OW_Component
{
    /**
     * @var MIDNIGHTTHEME_CLASS_AddSocialNetworkForm
     */
    protected $form;

    /**
     * Constructor.
     */
    public function __construct()
    {
        parent::__construct();

        $this->form = new MIDNIGHTTHEME_CLASS_AddSocialNetworkForm();
    }

    /**
     * On before render event.
     */
    public function onBeforeRender()
    {
        parent::onBeforeRender();

        $this->addForm($this->form);

        $imageElId = $this->form->getElement(MIDNIGHTTHEME_CLASS_AddSocialNetworkForm::FIELD_NAME_IMAGE)->getId();
        $imageTargetId = "image-preview";

        OW::getDocument()->addOnloadScript("
            async function urlIsSvg(url) {
                const r = await fetch(url, {method: 'HEAD'});
                return r.headers.get('content-type') === 'image/svg+xml';
            }

            $('#{$imageElId}').change(() => {
                var src = document.getElementById('{$imageElId}');
                var target = document.getElementById('{$imageTargetId}');
                var wrapper = document.getElementById('social-network-wrapper');
                var fr = new FileReader();
               
                if (!src.files[0]) {
                    return;
                }
                
                fr.readAsDataURL(src.files[0]);
                
                fr.onload = () => {
                    var img = new Image();
                    img.src = fr.result;
                    var isSvg = false;
                    var wrapperClass = '';
                    
                    if (img.src.indexOf('image/svg+xml') !== -1) {
                        isSvg = true;
                    }
                    
                    img.onload = function() {
                        var threshold = 128;
                        var canvas = document.createElement('canvas');
                        canvas.width = img.width;
                        canvas.height = img.height;
                        
                        var ctx = canvas.getContext('2d');
                        ctx.drawImage(img, 0, 0, img.width, img.height);
                        
                        var imageData = ctx.getImageData(0, 0, canvas.width, canvas.height);
                        var pixels = imageData.data;
                        var sumBrightness = 0;
                        
                        for (var i = 0; i < pixels.length; i += 4) {
                            var red = pixels[i];
                            var green = pixels[i + 1];
                            var blue = pixels[i + 2];
                            
                            var brightness = (red + green + blue) / 3;
                            
                            sumBrightness += brightness;
                        }
                        
                        var averageBrightness = sumBrightness / (img.width * img.height);
                        
                        wrapperClass = averageBrightness < threshold ? 'social-networks-light-bg' : 'social-networks-dark-bg';
                        if (isSvg) {
                            wrapperClass = averageBrightness < threshold ? 'social-networks-dark-bg' : 'social-networks-light-bg';
                        }
                        $(wrapper).removeClass();
                        $(wrapper).addClass(wrapperClass);
                        
                        target.src = fr.result;
                    };
                }; 
            });
        ");
        $this->assign('imageTargetId', $imageTargetId);
    }
}
