<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Edit how it works component class.
 */
class MIDNIGHTTHEME_CMP_EditHowItWorks extends OW_Component
{
    /**
     * @var MIDNIGHTTHEME_CLASS_EditHowItWorksForm
     */
    protected $form;

    protected $number;

    /**
     * Constructor.
     */
    public function __construct($number)
    {
        parent::__construct();

        $this->number = (int) $number;
        $this->form = new MIDNIGHTTHEME_CLASS_EditHowItWorksForm($this->number);
    }

    /**
     * On before render event.
     */
    public function onBeforeRender()
    {
        parent::onBeforeRender();

        $this->addForm($this->form);

        $imageElValue = $this->form->getElement(MIDNIGHTTHEME_CLASS_EditHowItWorksForm::FIELD_NAME_IMAGE)->getValue();
        $this->assign('imageSrc', $imageElValue);

        $imageElId = $this->form->getElement(MIDNIGHTTHEME_CLASS_EditHowItWorksForm::FIELD_NAME_IMAGE)->getId();
        $imageTargetId = "image-preview";

        OW::getDocument()->addOnloadScript("
            $('#{$imageElId}').change(() => {
                var src = document.getElementById('{$imageElId}');
                var target = document.getElementById('{$imageTargetId}');
                
                var fr = new FileReader();
                fr.onload = () => target.src = fr.result;
                fr.readAsDataURL(src.files[0]);
            });
        ");
        $this->assign('imageTargetId', $imageTargetId);

        $languageElId = $this->form->getElement(MIDNIGHTTHEME_CLASS_EditHowItWorksForm::FIELD_NAME_LANGUAGE)->getId();
        $titleElId = $this->form->getElement(MIDNIGHTTHEME_CLASS_EditHowItWorksForm::FIELD_NAME_TITLE)->getId();
        $textElId = $this->form->getElement(MIDNIGHTTHEME_CLASS_EditHowItWorksForm::FIELD_NAME_TEXT)->getId();
        $actionUrl = OW::getRouter()->urlForRoute("midnighttheme_fetch_how_it_works");
        $confirmationText = OW::getLanguage()->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_switch_language_confirmation');

        OW::getDocument()->addOnloadScript("
            const bodyEl$ = $('body');
            const languageEl$ = $('#{$languageElId}');
            const textEl$ = $('#{$textElId}');
            
            let prevVal = null;
            let changed = false;
            const fieldWatcher = () => changed = true;
            
            bodyEl$.on('change', '#{$textElId}', fieldWatcher);
            
            bodyEl$.on('focus', '#{$languageElId}', () => prevVal = languageEl$.val());
            bodyEl$.on('change', '#{$languageElId}', () => {
                if (changed && !confirm('{$confirmationText}')) {
                    languageEl$.val(prevVal);
                    return false;
                }
            
                const number = {$this->number};
                const langId = languageEl$.val();
                
                $.ajax({
                    url: '{$actionUrl}',
                    type: 'POST',
                    dataType: 'json',
                    data: { number: number, langId: langId },
                    beforeSend: () => {
                        languageEl$.attr('disabled', 'disabled');
                    },
                    success: (response) => {
                        textEl$.val(response['text']);
                        
                        languageEl$.removeAttr('disabled');
                        
                        changed = false;
                    }
                })
            });
        ");
    }
}
