<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Edit testimonials component class.
 */
class MIDNIGHTTHEME_CMP_EditTestimonials extends MIDNIGHTTHEME_CMP_AddTestimonials
{
    /**
     * @var MIDNIGHTTHEME_CLASS_EditTestimonialsForm
     */
    protected $form;

    protected $number;

    /**
     * Constructor.
     */
    public function __construct($number)
    {
        OW_Component::__construct();

        $this->number = (int) $number;
        $this->form = new MIDNIGHTTHEME_CLASS_EditTestimonialsForm($this->number);
    }

    /**
     * On before render event.
     */
    public function onBeforeRender()
    {
        parent::onBeforeRender();

        $imageElValue = $this->form->getElement(MIDNIGHTTHEME_CLASS_AddTestimonialsForm::FIELD_NAME_IMAGE)->getValue();
        $this->assign('imageSrc', $imageElValue);

        $languageElId = $this->form->getElement(MIDNIGHTTHEME_CLASS_AddTestimonialsForm::FIELD_NAME_LANGUAGE)->getId();
        $textElId = $this->form->getElement(MIDNIGHTTHEME_CLASS_AddTestimonialsForm::FIELD_NAME_TEXT)->getId();
        $nameElId = $this->form->getElement(MIDNIGHTTHEME_CLASS_AddTestimonialsForm::FIELD_NAME_NAME)->getId();
        $locationElId = $this->form->getElement(MIDNIGHTTHEME_CLASS_AddTestimonialsForm::FIELD_NAME_LOCATION)->getId();
        $actionUrl = OW::getRouter()->urlForRoute("midnighttheme_fetch_testimonials");
        $confirmationText = OW::getLanguage()->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_switch_language_confirmation');

        OW::getDocument()->addOnloadScript("
            const bodyEl$ = $('body');
            const languageEl$ = $('#{$languageElId}');
            const textEl$ = $('#{$textElId}');
            const nameEl$ = $('#{$nameElId}');
            const locationEl$ = $('#{$locationElId}');
            
            let prevVal = null;
            let changed = false;
            const fieldWatcher = () => changed = true;
            
            bodyEl$.on('change', '#{$textElId}', fieldWatcher);
            bodyEl$.on('change', '#{$nameElId}', fieldWatcher);
            bodyEl$.on('change', '#{$locationElId}', fieldWatcher);
            
            bodyEl$.on('focus', '#{$languageElId}', () => prevVal = languageEl$.val());
            bodyEl$.on('change', '#{$languageElId}', () => {
                if (changed && !confirm('{$confirmationText}')) {
                    languageEl$.val(prevVal);
                    return false;
                }
            
                const number = {$this->number};
                const langId = languageEl$.val();
                
                $.ajax({
                    url: '{$actionUrl}',
                    type: 'POST',
                    dataType: 'json',
                    data: { number: number, langId: langId },
                    beforeSend: () => {
                        languageEl$.attr('disabled', 'disabled');
                    },
                    success: (response) => {
                        textEl$.val(response['text']);
                        nameEl$.val(response['name']);
                        locationEl$.val(response['location']);
                        
                        languageEl$.removeAttr('disabled');
                        
                        changed = false;
                    }
                })
            });
        ");
    }
}
