<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for exclusive use with SkaDate Dating Software (http://www.skadate.com)
 * and is licensed under SkaDate Exclusive License by Skalfa LLC.
 *
 * Full text of this license can be found at http://www.skadate.com/sel.pdf
 */

/**
 * Quick links widget component class.
 */
class MIDNIGHTTHEME_CMP_QuickLinksWidget extends BASE_CMP_QuickLinksWidget
{
    const QL_BLOCKED_USER = "blocked_user";
    const QL_MY_CREDITS = "my_credits";
    const QL_MY_MATCHES = "my_matches";
    const QL_MY_EVENTS = "my_events";
    const QL_MY_FRIENDS = "my_friends";
    const QL_MY_BLOG = "my_blog";
    const QL_MY_BOOKMARKS = "my_bookmarks";
    const QL_MY_VIDEO = "my_video";
    const QL_MY_PHOTO_ALBUMS = "my_photo_albums";
    const QL_MY_GROUPS = "my_groups";
    const QL_MY_GIFTS = "my_gifts";

    const QUICK_LINK_ROUTE_NAMES = [
        self::QL_BLOCKED_USER => "users-blocked",
        self::QL_MY_CREDITS => "usercredits.buy_credits",
        self::QL_MY_MATCHES => "matchmaking_members_page",
        self::QL_MY_EVENTS => "event.view_event_list",
        self::QL_MY_FRIENDS => "friends_list",
        self::QL_MY_BLOG => "user-blog",
        self::QL_MY_BOOKMARKS => "bookmarks.list",
        self::QL_MY_VIDEO => "video_user_video_list",
        self::QL_MY_PHOTO_ALBUMS => "photo_user_albums",
        self::QL_MY_GROUPS => "groups-my-list",
        self::QL_MY_GIFTS => "virtual_gifts_private_list",
    ];

    const QUICK_LINK_CLASSES = [
        self::QL_BLOCKED_USER => "ow_ql_blocked",
        self::QL_MY_CREDITS => "ow_ql_credits",
        self::QL_MY_MATCHES => "ow_ql_matches",
        self::QL_MY_EVENTS => "ow_ql_events",
        self::QL_MY_FRIENDS => "ow_ql_friends",
        self::QL_MY_BLOG => "ow_ql_blog",
        self::QL_MY_BOOKMARKS => "ow_ql_bookmark",
        self::QL_MY_VIDEO => "ow_ql_video",
        self::QL_MY_PHOTO_ALBUMS => "ow_ql_photo",
        self::QL_MY_GROUPS => "ow_ql_groups",
        self::QL_MY_GIFTS => "ow_ql_gifts",
    ];

    public function __construct(BASE_CLASS_WidgetParameter $param)
    {
        parent::__construct($param);

        $router = OW::getRouter();

        $data = $this->assignedVars["data"];
        $routeSegments = [];

        foreach (self::QUICK_LINK_ROUTE_NAMES as $name => $routeName)
        {
            $route = $router->getRoute($routeName);

            if ($route)
            {
                $routeSegments[$name] = preg_replace("/:[a-z]+/i", "", $route->getRoutePath());
            }
        }

        foreach ($routeSegments as $name => $segment)
        {
            foreach ($data as $index => $quickLink)
            {
                if (strpos($quickLink["url"], $segment) !== false)
                {
                    $data[$index]["class"] = self::QUICK_LINK_CLASSES[$name];

                    break;
                }
            }
        }

        $this->assign("data", $data);
    }
}
