<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for use with Oxwall Free Community Software http://www.oxwall.com/
 * and is licensed under Oxwall Store Commercial License.
 *
 * Full text of this license can be found at http://developers.oxwall.com/store/oscl
 */

/**
 * Testimonials component class.
 */
class MIDNIGHTTHEME_CMP_TestimonialsSection extends OW_Component
{
    /**
     * Constructor.
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * On before render event.
     */
    public function onBeforeRender()
    {
        parent::onBeforeRender();

        // Import JS
        OW::getDocument()->addScript('https://unpkg.com/masonry-layout@4/dist/masonry.pkgd.min.js');

        $modernizrJsFileUrl = OW::getPluginManager()->getPlugin(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY)
                ->getStaticJsUrl() . "/modernizr-custom.js";
        OW::getDocument()->addScript($modernizrJsFileUrl);

        OW::getDocument()->addOnloadScript("
            window.onload = function() {
                $('.custom_midnight_qs_widget_index').addClass('ow_inprogress');
            }
        
            $('.testimonials_items').masonry({
                itemSelector: '.testimonials_item',
                gutter: 22
            });
            
            $('.testimonials_btn').click(function() {
                $('.testimonials').addClass('show_all');
                
                $(this).hide();
            });
            
            var itemMaxHeight = 0;
            handleWindowResize();
            
            function handleWindowResize() {
                var isWide = $(window).width() <= 480;
                var firstThreeDivs = $('.testimonials_items .testimonials_item:lt(3)');
                var maxHeight = 0;
    
                firstThreeDivs.each(function() {
                    var divHeight = $(this).outerHeight();
                
                    if (isWide) {
                        maxHeight += divHeight;
                    }
                    else {
                        if (divHeight > maxHeight) {
                            maxHeight = divHeight;
                        }
                    }
                });
                
                if (maxHeight != itemMaxHeight ) {
                    itemMaxHeight = maxHeight;
                    
                    $('.testimonials_items').css('max-height', (itemMaxHeight + 250) + 'px');
                }
            }
            
            $(window).resize(function() {
                handleWindowResize();
            });
        ");

        $testimonialsList = MIDNIGHTTHEME_BOL_Service::getInstance()->getTestimonialsList(0, 18);

        if ( OW::getConfig()->getValue(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'section_testimonials_is_random') )
        {
            shuffle($testimonialsList);
        }

        $this->assign('testimonialsList', $testimonialsList);
        $this->assign('showMore', count($testimonialsList) > 3);
    }
}