<?php

/**
 * Copyright (c) 2023, Skalfa LLC
 * All rights reserved.
 *
 * ATTENTION: This commercial software is intended for exclusive use with SkaDate Dating Software (http://www.skadate.com)
 * and is licensed under SkaDate Exclusive License by Skalfa LLC.
 *
 * Full text of this license can be found at http://www.skadate.com/sel.pdf
 */

/**
 * Admin controller class.
 */
class MIDNIGHTTHEME_CTRL_Admin extends ADMIN_CTRL_Abstract
{
    public function init()
    {
        parent::init();

        $handler = OW::getRequestHandler()->getHandlerAttributes();
        $language = OW::getLanguage();
        $router = OW::getRouter();
        $menus = [];

        $this->setPageHeading($language->text('midnighttheme', 'theme_settings'));

        $userStoriesSection = new BASE_MenuItem();
        $userStoriesSection->setLabel($language->text("midnighttheme", "admin_menu_header_label"));
        $userStoriesSection->setUrl($router->urlForRoute("midnighttheme_section_header"));
        $userStoriesSection->setActive($handler[OW_RequestHandler::ATTRS_KEY_ACTION] === "sectionHeader");
        $userStoriesSection->setKey("sectionHeader");
        $userStoriesSection->setIconClass("ow_ic_file");
        $userStoriesSection->setOrder(0);
        $menus[] = $userStoriesSection;

        $membersSection = new BASE_MenuItem();
        $membersSection->setLabel($language->text("midnighttheme", "admin_menu_members_label"));
        $membersSection->setUrl($router->urlForRoute("midnighttheme_section_members"));
        $membersSection->setActive($handler[OW_RequestHandler::ATTRS_KEY_ACTION] === "sectionMembers");
        $membersSection->setKey("sectionMembers");
        $membersSection->setIconClass("ow_ic_friends");
        $membersSection->setOrder(1);
        $menus[] = $membersSection;

        $howItWorksSection = new BASE_MenuItem();
        $howItWorksSection->setLabel($language->text("midnighttheme", "admin_menu_how_it_works_label"));
        $howItWorksSection->setUrl($router->urlForRoute("midnighttheme_section_how_it_works"));
        $howItWorksSection->setActive($handler[OW_RequestHandler::ATTRS_KEY_ACTION] === "sectionHowItWorks");
        $howItWorksSection->setKey("sectionHowItWorks");
        $howItWorksSection->setIconClass("ow_ic_info");
        $howItWorksSection->setOrder(2);
        $menus[] = $howItWorksSection;

        $testimonialsSection = new BASE_MenuItem();
        $testimonialsSection->setLabel($language->text("midnighttheme", "admin_menu_testimonials_label"));
        $testimonialsSection->setUrl($router->urlForRoute("midnighttheme_section_testimonials"));
        $testimonialsSection->setActive($handler[OW_RequestHandler::ATTRS_KEY_ACTION] === "sectionTestimonials");
        $testimonialsSection->setKey("sectionTestimonials");
        $testimonialsSection->setIconClass("ow_ic_edit");
        $testimonialsSection->setOrder(3);
        $menus[] = $testimonialsSection;

        $socialNetworksSection = new BASE_MenuItem();
        $socialNetworksSection->setLabel($language->text("midnighttheme", "admin_menu_social_networks_label"));
        $socialNetworksSection->setUrl($router->urlForRoute("midnighttheme_section_social_networks"));
        $socialNetworksSection->setActive($handler[OW_RequestHandler::ATTRS_KEY_ACTION] === "sectionSocialNetworks");
        $socialNetworksSection->setKey("sectionSocialNetworks");
        $socialNetworksSection->setIconClass("ow_ic_forum");
        $socialNetworksSection->setOrder(4);
        $menus[] = $socialNetworksSection;

        $this->addComponent("menu", new BASE_CMP_ContentMenu($menus));
    }
    
    public function sectionTestimonials()
    {
        /**
         * @var MIDNIGHTTHEME_BOL_Service $service
         */
        $service = MIDNIGHTTHEME_BOL_Service::getInstance();

        $form = new MIDNIGHTTHEME_CLASS_TestimonialsSettingsForm();
        $this->addForm($form);

        $onPage = 10;
        $page = isset($_GET['page']) && (int) $_GET['page'] ? (int) $_GET['page'] : 1;
        $first = ($page - 1) * $onPage;

        $testimonialsList = $service->getTestimonialsList($first, $onPage);
        $testimonialsCount = $service->getTestimonialsCount();

        // Paging
        $pages = (int) ceil($testimonialsCount / $onPage);
        $paging = new BASE_CMP_Paging($page, $pages, $onPage);

        $router = OW::getRouter();
        $language = OW::getLanguage();

        // Import admin styles
        $adminStylesFileUrl = OW::getPluginManager()->getPlugin(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY)->getStaticCssUrl() . "styles_admin.css";
        OW::getDocument()->addStyleSheet($adminStylesFileUrl);

        // Inline JS
        OW::getDocument()->addOnloadScript("
            $('#add-testimonials').click(function() {
                OW.ajaxFloatBox('MIDNIGHTTHEME_CMP_AddTestimonials', [], {
                    width: '600px',
                    title: '{$language->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_add_testimonials_cmp_label')}'
                });
            });
            $('#testimonials-table .testimonials-edit').click(function() {
                var number = $(this).attr('number');
            
                OW.ajaxFloatBox('MIDNIGHTTHEME_CMP_EditTestimonials', [number], {
                    width: '600px',
                    title: '{$language->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_edit_testimonials_cmp_label')}'
                });
                
                return false;
            });
            $('#testimonials-table .testimonials-delete').click(function() {
                var number = $(this).attr('number');
            
                if (confirm('{$language->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_delete_testimonials_confirmation')}')) {
                    $.ajax({
                        type: 'POST',
                        url: '{$router->urlForRoute('midnighttheme_delete_handler_testimonials')}',
                        data: { number: number },
                        success: (result) => {
                            OW.info('{$language->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_testimonials_deleted_message')}');
                        
                            setTimeout(() => location.href = '{$router->urlForRoute('midnighttheme_section_testimonials')}', 1000);
                        }
                    });
                }
                
                return false;
            });
        ");

        $this->assign('first', $first);
        $this->assign('testimonialsList', $testimonialsList);
        $this->assign('testimonialsCount', $testimonialsCount);
        $this->assign('isRemovable', $testimonialsCount > 3);
        $this->addComponent('paging', $paging);
    }

    public function sectionHowItWorks()
    {
        /**
         * @var MIDNIGHTTHEME_BOL_Service $service
         */
        $service = MIDNIGHTTHEME_BOL_Service::getInstance();
        $language = OW::getLanguage();

        // Import admin styles
        $adminStylesFileUrl = OW::getPluginManager()->getPlugin(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY)->getStaticCssUrl() . "styles_admin.css";
        OW::getDocument()->addStyleSheet($adminStylesFileUrl);

        $howItWorksList = $service->getHowItWorksList();
        $howItWorksCount = $service->getHowItWorksCount();

        // Inline JS
        OW::getDocument()->addOnloadScript("
            $('#how-it-works-table .how-it-works-edit').click(function() {
                var number = $(this).attr('number');
            
                OW.ajaxFloatBox('MIDNIGHTTHEME_CMP_EditHowItWorks', [number], {
                    width: '600px',
                    title: '{$language->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_edit_how_it_works_cmp_label')}'
                });
                
                return false;
            });
        ");

        $this->assign('howItWorksList', $howItWorksList);
        $this->assign('howItWorksCount', $howItWorksCount);
    }

    public function sectionSocialNetworks()
    {
        /** @var MIDNIGHTTHEME_BOL_Service $service */
        $service = MIDNIGHTTHEME_BOL_Service::getInstance();
        $router = OW::getRouter();
        $language = OW::getLanguage();
        $document = OW::getDocument();

        $document->addScript(OW::getPluginManager()->getPlugin('base')->getStaticJsUrl() . 'jquery-ui.min.js');
        $document->addScript(OW::getPluginManager()->getPlugin(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY)->getStaticJsUrl() . 'drag.js');

        $networkList = $service->getSocialNetworks();

        // Import admin styles
        $adminStylesFileUrl = OW::getPluginManager()->getPlugin(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY)->getStaticCssUrl() . "styles_admin.css";
        $document->addStyleSheet($adminStylesFileUrl);


        $this->assign('networkList', $networkList);

        $document->addOnloadScript(UTIL_JsGenerator::composeJsString(';window.ajaxDragParams({$params});', [
            'params' => [
                'actionUrl' => $router->urlForRoute('midnighttheme_social_network_reorder'),
            ]
        ]));

        $document->addOnloadScript("
            $('#add-social-network').click(function() {
                OW.ajaxFloatBox('MIDNIGHTTHEME_CMP_AddSocialNetwork', [], {
                    width: '600px',
                    title: '{$language->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_add_social_network_cmp_label')}'
                });
            });
            $('#social-networks-table .social-network-edit').click(function() {
                var id = $(this).data('id');
            
                OW.ajaxFloatBox('MIDNIGHTTHEME_CMP_EditSocialNetwork', [id], {
                    width: '600px',
                    title: '{$language->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_edit_social_network_cmp_label')}'
                });
                
                return false;
            });
            $('#social-networks-table .social-network-delete').click(function() {
                var id = $(this).data('id');
            
                if (confirm('{$language->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_delete_social_network_confirmation')}')) {
                    $.ajax({
                        type: 'POST',
                        url: '{$router->urlForRoute('midnighttheme_delete_handler_social_network')}',
                        data: { id: id },
                        success: (result) => {
                            OW.info('{$language->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_social_network_deleted_message')}');
                        
                            setTimeout(() => location.href = '{$router->urlForRoute('midnighttheme_section_social_networks')}', 1000);
                        }
                    });
                }
                
                return false;
            });
        ");

        $this->assign('first', 0);
    }

    public function sectionHeader()
    {
        $language = OW::getLanguage();
        $router = OW::getRouter();
        $pluginKey = MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY;
        $config = OW::getConfig();
        $path = OW::getPluginManager()->getPlugin($pluginKey)->getUserFilesUrl() . "images/";

        $headerList = [
            $path . $config->getValue($pluginKey, "section_header_img_1") . "?" . uniqid(),
            $path . $config->getValue($pluginKey, "section_header_img_2") . "?" . uniqid(),
            $path . $config->getValue($pluginKey, "section_header_img_3") . "?" . uniqid(),
        ];

        // Import admin styles
        $adminStylesFileUrl = OW::getPluginManager()->getPlugin(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY)->getStaticCssUrl() . "styles_admin.css";
        OW::getDocument()->addStyleSheet($adminStylesFileUrl);

        OW::getLanguage()->addKeyForJs($pluginKey, 'admin_edit_header_item_cmp_label_1');
        OW::getLanguage()->addKeyForJs($pluginKey, 'admin_edit_header_item_cmp_label_2');
        OW::getLanguage()->addKeyForJs($pluginKey, 'admin_edit_header_item_cmp_label_3');

        // Inline JS
        OW::getDocument()->addOnloadScript("
            $('#header-table .header-item-edit').click(function() {
                var number = $(this).data('number');
        
                OW.ajaxFloatBox('MIDNIGHTTHEME_CMP_EditHeaderItem', [number], {
                    width: '600px',
                    title: OW.getLanguageText('{$pluginKey}', 'admin_edit_header_item_cmp_label_'+ number),
                });
                
                return false;
            });
            
            $('#header-table .header-item-reset').click(function() {
                var id = $(this).data('number');
            
                if (confirm('{$language->text($pluginKey, 'admin_reset_header_confirmation')}')) {
                    $.ajax({
                        type: 'POST',
                        url: '{$router->urlForRoute('midnighttheme_reset_handler_header')}',
                        data: { id: id },
                        success: (result) => {
                            OW.info('{$language->text($pluginKey, 'admin_header_reset_message')}');
                        
                            setTimeout(() => location.href = '{$router->urlForRoute('midnighttheme_section_header')}', 1000);
                        }
                    });
                }
                
                return false;
            });
        ");

        $this->assign('first', 0);
        $this->assign('headerList', $headerList);
    }

    public function sectionMembers()
    {
        /**
         * @var MIDNIGHTTHEME_BOL_Service $service
         */
        $service = MIDNIGHTTHEME_BOL_Service::getInstance();
        $pluginKey = MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY;
        $router = OW::getRouter();
        $language = OW::getLanguage();

        if ( OW::getRequest()->isPost() && !empty($_POST['users']) )
        {
            $users = $_POST['users'];

            if ( isset($_POST['deactivate']) || isset($_POST['activate']) )
            {
                $service->setMembersActiveByIds($users, isset($_POST['activate']));

                OW::getFeedback()->info($language->text($pluginKey,'members_feedback_modified'));
            }

            OW::getApplication()->redirect(OW::getRequest()->buildUrlQueryString());
        }

        $form = new MIDNIGHTTHEME_CLASS_MembersSettingsForm();
        $this->addForm($form);

        if ( OW::getRequest()->isAjax() && OW::getRequest()->isPost() && $form->isValid($_POST) )
        {
            if ($_POST['isRealUsers'] == 'on')
            {
                $realUserList = $service->getLatestUserList();
                if ( count($realUserList) < 6 )
                {
                    OW::getFeedback()->error(
                        $language->text($pluginKey, 'section_members_is_real_users', [ 'count'=> 6]));
                    $this->redirect();
                }
            }

            $form->process();

            OW::getFeedback()->info($language->text($pluginKey, 'members_settings_updated'));
            $this->redirect();
        }

        $hideFakeUsers = (bool)OW::getConfig()->getValue(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'section_members_is_real_users');
        $this->assign('hideFakeUsers', $hideFakeUsers);

        $membersList = $service->getMembers();
        $membersCount = count($membersList);

        // Import admin styles
        $adminStylesFileUrl = OW::getPluginManager()
                ->getPlugin(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY)->getStaticCssUrl() . "styles_admin.css";
        OW::getDocument()->addStyleSheet($adminStylesFileUrl);

        // Inline JS
        OW::getDocument()->addOnloadScript("
            $('#add-members').click(function() {
                OW.ajaxFloatBox('MIDNIGHTTHEME_CMP_AddMembers', [], {
                    width: '600px',
                    title: '{$language->text(
                        MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_add_members_cmp_label')}'
                });
            });
            $('#members-table .members-edit').click(function() {
                var number = $(this).attr('number');
            
                OW.ajaxFloatBox('MIDNIGHTTHEME_CMP_EditMembers', [number], {
                    width: '600px',
                    title: '{$language->text(
                        MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_edit_members_cmp_label')}'
                });
                
                return false;
            });
            $('#members-table .members-delete').click(function() {
                var number = $(this).attr('number');
            
                if (confirm('{$language->text(
                    MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_delete_members_confirmation')}')) {
                    $.ajax({
                        type: 'POST',
                        url: '{$router->urlForRoute('midnighttheme_delete_handler_members')}',
                        data: { number: number },
                        success: (result) => {
                            OW.info('{$language->text(
                                MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_members_deleted_message')}');
                        
                            setTimeout(() => location.href = '{$router->urlForRoute('midnighttheme_section_members')}', 1000);
                        }
                    });
                }
                
                return false;
            });
            $('#members-table .members-checkbox').change(function() {
                var itemCount = $('#members-table .members-checkbox:checked').length;
                var allCount = $('#members-table .members-visible[data-visible=1]').length;
                
                if ($('#members-table .members-checkbox').length - itemCount < 6) {
                    OW.error('" . $language->text($pluginKey, 'section_members_selected_error', [ 'count'=> 5]) . "');
                    $(this).attr('checked', false);
                }
            });
            $('#deactivate_user_btn').click(function() {
                var yesCount = $('#members-table .members-visible[data-visible=1]').length;
                var selectedYesCount = $('#members-table tr:has(.members-checkbox:checked) .members-visible[data-visible=1]').length;
                
                if ((yesCount - selectedYesCount) < 6) {
                    OW.error('" . $language->text($pluginKey, 'section_members_selected_error', [ 'count'=> 5]) . "');
                    
                    return false;
                }
            });
        ");

        $this->assign('membersCount', count($membersList));
        $this->assign('first', 0);
        $this->assign('isMax', $membersCount >= 18);
        $this->assign('isRemovable', $membersCount > 12);
        $this->assign('membersList', $membersList);
        $this->assign('max', 18);
        $this->assign('min', 12);
    }

    public function addMembersHandler()
    {
        $form = new MIDNIGHTTHEME_CLASS_AddMembersForm();

        if (OW::getRequest()->isPost() && isset($_POST['form_name']) && $_POST['form_name'] === $form->getName())
        {
            $form->process($_POST);

            OW::getFeedback()->info(OW::getLanguage()
                ->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_feedback_members_added'));
        }

        $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_members'));
    }

    public function editMembersHandler()
    {
        if (!isset($_POST['number']))
        {
            $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_members'));
        }

        $form = new MIDNIGHTTHEME_CLASS_EditMembersForm((int) $_POST['number']);

        if (OW::getRequest()->isPost() && isset($_POST['form_name']) && $_POST['form_name'] === $form->getName())
        {
            $form->process($_POST);

            OW::getFeedback()->info(OW::getLanguage()
                ->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_feedback_members_edited'));
        }

        $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_members'));
    }

    public function deleteMembersHandler()
    {
        if ( isset($_POST["number"]) )
        {
            $number = (int) $_POST["number"];

            MIDNIGHTTHEME_BOL_Service::getInstance()->deleteMember($number);
            MIDNIGHTTHEME_BOL_Service::getInstance()->updateNumberMembers($number);
        }

        exit;
    }

    public function addTestimonialsHandler()
    {
        if (!isset($_POST['language']))
        {
            $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_testimonials'));
        }

        $form = new MIDNIGHTTHEME_CLASS_AddTestimonialsForm();

        if (OW::getRequest()->isPost() && isset($_POST['form_name']) && $_POST['form_name'] === $form->getName())
        {
            $form->process($_POST);

            $language = BOL_LanguageService::getInstance()->findById((int) $_POST['language']);
            OW::getFeedback()->info(OW::getLanguage()
                ->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_feedback_testimonials_added', ['langName' => $language->label]));
        }

        $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_testimonials'));
    }

    public function editHeaderItemHandler()
    {
        $form = new MIDNIGHTTHEME_CLASS_EditHeaderItemForm((int) $_POST['number']);

        if (OW::getRequest()->isPost() && isset($_POST['form_name']) && $_POST['form_name'] === $form->getName())
        {
            $form->process($_POST);

            OW::getFeedback()->info(OW::getLanguage()
                ->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_feedback_header_item_edited'));
        }

        $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_header'));
    }

    public function resetHeaderHandler()
    {
        if ( isset($_POST["id"]) )
        {
            $id = (int) $_POST["id"];

            MIDNIGHTTHEME_BOL_Service::getInstance()->resetHeaderById($id);
        }

        exit;
    }

    public function editTestimonialsHandler()
    {
        if (!isset($_POST['number'], $_POST['language']))
        {
            $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_testimonials'));
        }

        $form = new MIDNIGHTTHEME_CLASS_EditTestimonialsForm((int) $_POST['number']);

        if (OW::getRequest()->isPost() && isset($_POST['form_name']) && $_POST['form_name'] === $form->getName())
        {
            $form->process($_POST);

            $language = BOL_LanguageService::getInstance()->findById((int) $_POST['language']);
            OW::getFeedback()->info(OW::getLanguage()
                ->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_feedback_testimonials_edited', ['langName' => $language->label]));
        }

        $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_testimonials'));
    }

    public function deleteTestimonialsHandler()
    {
        if (isset($_POST["number"]))
        {
            $number = (int) $_POST["number"];

            MIDNIGHTTHEME_BOL_Service::getInstance()->deleteTestimonials($number);
        }

        exit;
    }

    public function fetchTestimonialsDataByNumberAndLangId()
    {
        $data = [];

        if (isset($_POST["number"], $_POST["langId"]))
        {
            $number = (int) $_POST["number"];
            $langId = (int) $_POST["langId"];

            $data = MIDNIGHTTHEME_BOL_Service::getInstance()->getTestimonialsByNumberAndLangId($number, $langId);
        }

        echo json_encode($data);
        exit;
    }

    public function editHowItWorksHandler()
    {
        if (!isset($_POST['number'], $_POST['language']))
        {
            $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_how_it_works'));
        }

        $form = new MIDNIGHTTHEME_CLASS_EditHowItWorksForm((int) $_POST['number']);

        if (OW::getRequest()->isPost() && isset($_POST['form_name']) && $_POST['form_name'] === $form->getName())
        {
            $form->process($_POST);

            $language = BOL_LanguageService::getInstance()->findById((int) $_POST['language']);
            OW::getFeedback()->info(OW::getLanguage()
                ->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_feedback_how_it_works_edited', ['langName' => $language->label]));
        }

        $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_how_it_works'));
    }

    public function fetchHowItWorksByNumberAndLangId()
    {
        $data = [];

        if (isset($_POST["number"], $_POST["langId"]))
        {
            $number = (int) $_POST["number"];
            $langId = (int) $_POST["langId"];

            $data = MIDNIGHTTHEME_BOL_Service::getInstance()->getHowItWorksByNumberAndLangId($number, $langId);
        }

        echo json_encode($data);
        exit;
    }

    public function editSocialNetworksHandler()
    {
        $form = new MIDNIGHTTHEME_CLASS_EditSocialNetworksForm();

        if (OW::getRequest()->isPost() && isset($_POST['form_name']) && $_POST['form_name'] === $form->getName())
        {
            $form->process($_POST);

            OW::getFeedback()->info(OW::getLanguage()
                ->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_feedback_social_networks_edited'));
        }

        $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_social_networks'));
    }


    public function addSocialNetworkHandler()
    {
        $form = new MIDNIGHTTHEME_CLASS_AddSocialNetworkForm();

        if (OW::getRequest()->isPost() && isset($_POST['form_name']) && $_POST['form_name'] === $form->getName())
        {
            $form->process($_POST);

            OW::getFeedback()->info(OW::getLanguage()
                ->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_feedback_social_network_added'));
        }

        $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_social_networks'));
    }

    public function editSocialNetworkHandler()
    {
        if (!isset($_POST['id']))
        {
            $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_social_networks'));
        }

        $form = new MIDNIGHTTHEME_CLASS_EditSocialNetworkForm((int) $_POST['id']);

        if (OW::getRequest()->isPost() && isset($_POST['form_name']) && $_POST['form_name'] === $form->getName())
        {
            $form->process($_POST);

            OW::getFeedback()->info(OW::getLanguage()
                ->text(MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'admin_feedback_social_network_edited'));
        }

        $this->redirect(OW::getRouter()->urlForRoute('midnighttheme_section_social_networks'));
    }

    public function deleteSocialNetworkHandler()
    {
        if ( isset($_POST["id"]) )
        {
            $id = (int) $_POST["id"];

            MIDNIGHTTHEME_BOL_Service::getInstance()->deleteSocialNetwork($id);
        }

        exit;
    }

    public function ajaxReorder()
    {
        if ( !OW::getRequest()->isAjax() )
        {
            throw new Redirect404Exception();
        }

        $ids = [];
        foreach ( $_POST['ids'] as $key => $item )
        {
            $ids[$item['id']] = $key;
        }

        MIDNIGHTTHEME_BOL_Service::getInstance()->updateSocialNetworksOrder($ids);

        exit();
    }

    public function ajaxSaveConfigs()
    {
        if ( !OW::getRequest()->isAjax() )
        {
            throw new Redirect404Exception();
        }

        if ( $_POST['form_name'] == 'members-settings-form' )
        {
            if ( isset($_POST['isRealUsers']) && $_POST['isRealUsers'] == 'on' )
            {
                $realUserList = MIDNIGHTTHEME_BOL_Service::getInstance()->getLatestUserList();
                if ( count($realUserList) < 6 )
                {
                    exit(json_encode(['result' => false, 'message' => OW::getLanguage()->text(
                        MIDNIGHTTHEME_BOL_Service::PLUGIN_KEY, 'section_members_is_real_users', [ 'count'=> 5])]));
                }
            }

            $form = new MIDNIGHTTHEME_CLASS_MembersSettingsForm();
            $form->process($_POST);

            exit(json_encode(['result' => true, 'hideMembers' => isset($_POST['isRealUsers']) && $_POST['isRealUsers'] == 'on']));
        }

        if ( $_POST['form_name'] == 'testimonials-settings-form' )
        {
            $pass = new MIDNIGHTTHEME_CLASS_TestimonialsSettingsForm();
            $pass->process($_POST);

            exit(json_encode(['result' => true]));
        }

        exit();
    }
}
